@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.099_04';
+our $VERSION = '0.099_05';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Wed Jul 11 13:36:26 2018 GMT
+# on Fri Jul 13 14:43:18 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1762,7 +1762,7 @@ __PACKAGE__->status( add => 25431, iridium => 'D', 'Iridium 3', 'Decayed 2018-02
 __PACKAGE__->status( add => 25432, iridium => 'S', 'Iridium 76', '' );
 __PACKAGE__->status( add => 25467, iridium => '-', 'Iridium 82', 'Tumbling' );
 __PACKAGE__->status( add => 25468, iridium => '-', 'Iridium 81', 'Tumbling' );
-__PACKAGE__->status( add => 25469, iridium => '+', 'Iridium 80', '' );
+__PACKAGE__->status( add => 25469, iridium => 'S', 'Iridium 80', '' );
 __PACKAGE__->status( add => 25470, iridium => 'D', 'Iridium 79', 'Decayed 2000-11-29' );
 __PACKAGE__->status( add => 25471, iridium => 'D', 'Iridium 77', 'Decayed 2017-09-22' );
 __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
@@ -1783,8 +1783,8 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'S', 'Iridium 98', '' );
 
 # Summary:
-# Operational [+]: 18
-#       Spare [S]: 16
+# Operational [+]: 17
+#       Spare [S]: 17
 #    Tumbling [-]: 38
 #     Decayed [D]: 25
 
